==> style-o-matic-1.1.5.tgz: package/es/components/ToolBar/ToolBarIcon.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, getElementType, setCorePropDefaults, ROLE } from "../../lib";

var ToolBarIcon = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBarIcon, _CoreComponent);

  function ToolBarIcon() {
    _classCallCheck(this, ToolBarIcon);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolBarIcon.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        children = _getValidProps.children,
        props = _getValidProps.props;

    var ElementType = getElementType(ToolBarIcon, this.props);

    return React.createElement(
      ElementType,
      props,
      children
    );
  };

  return ToolBarIcon;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.ICON
}), _temp);


export default ToolBarIcon;

==> style-o-matic-1.1.37.tgz: package/es/components/ToolBar/ToolBarIcon.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, getElementType, getCorePropDefaults, ROLE } from "../../lib";

var ToolBarIcon = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBarIcon, _CoreComponent);

  function ToolBarIcon() {
    _classCallCheck(this, ToolBarIcon);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolBarIcon.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        children = _getValidProps.children,
        props = _getValidProps.props;

    var ElementType = getElementType(ToolBarIcon, this.props);

    return React.createElement(
      ElementType,
      props,
      children
    );
  };

  return ToolBarIcon;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.ICON
}), _temp);


export default ToolBarIcon;
